@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -64,7 +64,8 @@ class CloudFunctionsServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = CloudFunctionsServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[CloudFunctionsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -172,10 +173,16 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def cloud_function_path(project: str, location: str, function: str,) -> str:
+    def cloud_function_path(
+        project: str,
+        location: str,
+        function: str,
+    ) -> str:
         """Returns a fully-qualified cloud_function string."""
         return "projects/{project}/locations/{location}/functions/{function}".format(
-            project=project, location=location, function=function,
+            project=project,
+            location=location,
+            function=function,
         )
 
     @staticmethod
@@ -189,7 +196,10 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
     @staticmethod
     def crypto_key_path(
-        project: str, location: str, key_ring: str, crypto_key: str,
+        project: str,
+        location: str,
+        key_ring: str,
+        crypto_key: str,
     ) -> str:
         """Returns a fully-qualified crypto_key string."""
         return "projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}".format(
@@ -209,10 +219,18 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def repository_path(project: str, location: str, repository: str,) -> str:
+    def repository_path(
+        project: str,
+        location: str,
+        repository: str,
+    ) -> str:
         """Returns a fully-qualified repository string."""
-        return "projects/{project}/locations/{location}/repositories/{repository}".format(
-            project=project, location=location, repository=repository,
+        return (
+            "projects/{project}/locations/{location}/repositories/{repository}".format(
+                project=project,
+                location=location,
+                repository=repository,
+            )
         )
 
     @staticmethod
@@ -225,7 +243,9 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -238,9 +258,13 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -249,9 +273,13 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -260,9 +288,13 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -271,10 +303,14 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -459,7 +495,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Returns a list of functions that belong to the
         requested project.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -516,12 +551,20 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListFunctionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -539,7 +582,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Returns a function with the given name from the
         requested project.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -617,7 +659,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -636,7 +683,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         already exists in the specified project, the long running
         operation will return ``ALREADY_EXISTS`` error.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -730,7 +776,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -840,7 +891,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -867,7 +923,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         trigger, the trigger will be updated to remove this
         function.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -959,7 +1014,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -987,7 +1047,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         information on the actual limits, refer to `Rate
         Limits <https://cloud.google.com/functions/quotas#rate_limits>`__.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -1070,7 +1129,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1112,7 +1176,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         -  ``Authorization: Bearer YOUR_TOKEN``
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -1164,7 +1227,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1184,7 +1252,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         For more information about the signed URL usage see:
         https://cloud.google.com/storage/docs/access-control/signed-urls
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
@@ -1236,7 +1303,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1252,17 +1324,17 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Sets the IAM access control policy on the specified
         function. Replaces any existing policy.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_set_iam_policy():
                 # Create a client
                 client = functions_v1.CloudFunctionsServiceClient()
 
                 # Initialize request argument(s)
-                request = functions_v1.SetIamPolicyRequest(
+                request = iam_policy_pb2.SetIamPolicyRequest(
                     resource="resource_value",
                 )
 
@@ -1284,21 +1356,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1313,17 +1390,17 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1334,11 +1411,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1361,7 +1439,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1378,17 +1461,17 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         Returns an empty policy if the function exists and does
         not have a policy set.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_get_iam_policy():
                 # Create a client
                 client = functions_v1.CloudFunctionsServiceClient()
 
                 # Initialize request argument(s)
-                request = functions_v1.GetIamPolicyRequest(
+                request = iam_policy_pb2.GetIamPolicyRequest(
                     resource="resource_value",
                 )
 
@@ -1410,21 +1493,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1439,17 +1527,17 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1460,11 +1548,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1487,7 +1576,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1504,17 +1598,17 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         policy for a function. If the function does not exist, this will
         return an empty set of permissions, not a NOT_FOUND error.
 
-
         .. code-block:: python
 
             from google.cloud import functions_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
             def sample_test_iam_permissions():
                 # Create a client
                 client = functions_v1.CloudFunctionsServiceClient()
 
                 # Initialize request argument(s)
-                request = functions_v1.TestIamPermissionsRequest(
+                request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
                     permissions=['permissions_value_1', 'permissions_value_2'],
                 )
@@ -1559,7 +1653,12 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1580,7 +1679,9 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-functions",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-functions",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
